Deeper look into connections
****************************

.. important::

    .. todo complete reworking of this section

    Please note that this part of the documentation is not yet finished. It will still be revised and updated.

Connections are a important component of the Balder ecosystem. Your connection statements can assume different states.
This sections help to understand how the connection mechanism is implemented inside Balder.


